==> bitcoin-abc-0.28.9.tar.gz: bitcoin-abc-0.28.9/web/e.cash/data/wallets.js <==
// Copyright (c) 2023 The Bitcoin developers
// Distributed under the MIT software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.
export const wallets = [
    {
        name: 'Cashtab',
        text: 'Cashtab is an open source, highly secure, non-custodial web wallet for eCash (XEC) & eTokens. Cashtab is a fast, secure & easy-to-use XEC wallet! Cashtab is also available as a browser extension for Google Chrome and Brave.',
        image: '/images/cashtab.png',
        link: 'https://cashtab.com/',
        availableOn: ['Web App', 'Web Extension'],
        features: ['eTokens', 'Message Signing'],
    },
    {
        name: 'Electrum ABC',
        text: 'Electrum ABC is a fast and highly secure eCash (XEC) wallet for Windows, MacOS, and Linux. It supports mnemonic seed phrases, hardware wallets, multi-sig wallets, and importing private keys. Electrum ABC is a non-custodial XEC wallet for power users!',
        image: '/images/electrum-abc.png',
        link: 'https://www.bitcoinabc.org/electrum/',
        availableOn: ['Desktop'],
        features: ['Message Signing', 'Multi-sig wallets'],
    },
    {
        name: 'RaiPay',
        text: "RaiPay is a non-custodial mobile wallet for storing & managing eCash (XEC) & eTokens. With RaiPay you can experience the power and speed of eCash (XEC) and eTokens online, in person, and everywhere else. It's available for both Android & iOS devices.",
        image: '/images/raipay.png',
        link: 'https://www.raipay.co',
        availableOn: ['iOS', 'Android'],
        features: ['eTokens', 'Message Signing'],
    },
    {
        name: 'ViaWallet',
        text: 'Backed by CoinEx, ViaWallet is a multi-chain non-custodial mobile wallet that supports eCash (XEC). With ViaWallet you can send, receive and manage your XEC coins securely. ViaWallet is available for both Android & iOS devices.',
        image: '/images/via-wallet.png',
        link: 'https://viawallet.com/',
        availableOn: ['iOS', 'Android'],
    },
    {
        name: 'AbcPay',
        text: "AbcPay is an advanced multi-currency crypto wallet for mobile devices, supporting eCash (XEC) and eTokens. AbcPay provides cutting edge features such as multi-signature wallet, 2FA and biometric authentication. It's available for both Android & iOS devices.",
        image: '/images/abc-pay.png',
        link: 'https://abcpay.cash/',
        availableOn: ['iOS', 'Android'],
        features: ['eTokens', 'Message Signing', 'Multi-sig wallets'],
    },
    {
        name: 'Arctic Wallet',
        text: 'Arctic Wallet is a non-custodial crypto wallet built on the principles of decentralization and privacy supporting eCash (XEC). With Arctic Wallet, you can send, receive and store XEC safely and securely. Arctic wallet is available for desktop and mobile platforms.',
        image: '/images/artic-wallet.png',
        link: 'https://arcticwallet.io/',
        availableOn: ['iOS', 'Android', 'Desktop'],
    },
    {
        name: 'Unstoppable Wallet',
        text: 'A privacy-oriented non-custodial wallet for eCash (XEC). Unstoppable is a highly secure, decentralized, and open-source wallet, available for Android and iOS smartphones.',
        image: '/images/unstoppable-wallet.png',
        link: 'https://unstoppable.money/',
        availableOn: ['iOS', 'Android'],
    },
    {
        name: 'Stack Wallet',
        text: 'An open-source, non-custodial multichain wallet for eCash (XEC). Stack is a highly secure, privacy-first mobile wallet for XEC, available for Android and iOS smartphones.',
        image: '/images/stack-wallet.png',
        link: 'https://stackwallet.com/',
        availableOn: ['iOS', 'Android'],
    },
    {
        name: 'Satochip',
        text: 'Satochip is an open source and super-secure multi-crypto hardware wallet that natively supports storing eCash (XEC). Satochip cold wallet offers state-of-the-art security for storing & managing your XEC coins.',
        image: '/images/satochip.svg',
        link: 'https://satochip.io/',
        availableOn: ['Hardware Wallet'],
    },
    {
        name: "D'CENT",
        text: "D'CENT is another major hardware wallet that natively supports eCash (XEC). With the D’CENT biometric hardware wallet, you can securely send, receive, and manage your XEC coins.",
        image: '/images/dcent.svg',
        link: 'https://dcentwallet.com/',
        availableOn: ['Hardware Wallet'],
    },
    {
        name: 'Ballet',
        text: 'Ballet is a secure non-electronic physical wallet that offers native support for eCash (XEC). Safely store and easily manage your XEC coins with the Ballet cold wallet.',
        image: '/images/ballet.png',
        link: 'https://www.ballet.com/',
        availableOn: ['Hardware Wallet'],
    },
];

==> bitcoin-abc-0.29.1.tar.gz: bitcoin-abc-0.29.1/web/e.cash/data/wallets.js <==
// Copyright (c) 2023 The Bitcoin developers
// Distributed under the MIT software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.
export const wallets = [
    {
        name: 'Cashtab Web',
        text: 'Cashtab (Web) is an open source, highly secure, non-custodial web wallet for eCash (XEC) & eTokens. It is a fast & easy-to-use XEC wallet designed for everyday use.',
        image: '/images/cashtab.png',
        link: 'https://cashtab.com/',
        availableOn: ['Web App'],
        features: ['eTokens', 'Message Signing'],
    },
    {
        name: 'Cashtab Extension',
        text: 'Cashtab (Extension) is a browser-integrated version of Cashtab Web for Google Chrome and Brave browsers. No sign-in or account required. Think MetaMask for eCash.',
        image: '/images/cashtab-extension.png',
        link: 'https://chromewebstore.google.com/detail/cashtab/obldfcmebhllhjlhjbnghaipekcppeag',
        availableOn: ['Browser Extension'],
        features: ['eTokens', 'Message Signing'],
    },
    {
        name: 'Electrum ABC',
        text: 'Electrum ABC is a fast and highly secure eCash (XEC) wallet for Windows, MacOS, and Linux. It supports mnemonic seed phrases, hardware wallets, multi-sig wallets, and importing private keys. Electrum ABC is a non-custodial XEC wallet for power users!',
        image: '/images/electrum-abc.png',
        link: 'https://www.bitcoinabc.org/electrum/',
        availableOn: ['Desktop'],
        features: ['Message Signing', 'Multi-sig wallets'],
    },
    {
        name: 'RaiPay',
        text: "RaiPay is a non-custodial mobile wallet for storing & managing eCash (XEC) & eTokens. With RaiPay you can experience the power and speed of eCash (XEC) and eTokens online, in person, and everywhere else. It's available for both Android & iOS devices.",
        image: '/images/raipay.png',
        link: 'https://www.raipay.co',
        availableOn: ['iOS', 'Android'],
        features: ['eTokens', 'Message Signing'],
    },
    {
        name: 'ViaWallet',
        text: 'Backed by CoinEx, ViaWallet is a multi-chain non-custodial mobile wallet that supports eCash (XEC). With ViaWallet you can send, receive and manage your XEC coins securely. ViaWallet is available for both Android & iOS devices.',
        image: '/images/via-wallet.png',
        link: 'https://viawallet.com/',
        availableOn: ['iOS', 'Android'],
    },
    {
        name: 'AbcPay',
        text: "AbcPay is an advanced multi-currency crypto wallet for mobile devices, supporting eCash (XEC) and eTokens. AbcPay provides cutting edge features such as multi-signature wallet, 2FA and biometric authentication. It's available for both Android & iOS devices.",
        image: '/images/abc-pay.png',
        link: 'https://abcpay.cash/',
        availableOn: ['iOS', 'Android'],
        features: ['eTokens', 'Message Signing', 'Multi-sig wallets'],
    },
    {
        name: 'Arctic Wallet',
        text: 'Arctic Wallet is a non-custodial crypto wallet built on the principles of decentralization and privacy supporting eCash (XEC). With Arctic Wallet, you can send, receive and store XEC safely and securely. Arctic wallet is available for desktop and mobile platforms.',
        image: '/images/artic-wallet.png',
        link: 'https://arcticwallet.io/',
        availableOn: ['iOS', 'Android', 'Desktop'],
    },
    {
        name: 'Unstoppable Wallet',
        text: 'A privacy-oriented non-custodial wallet for eCash (XEC). Unstoppable is a highly secure, decentralized, and open-source wallet, available for Android and iOS smartphones.',
        image: '/images/unstoppable-wallet.png',
        link: 'https://unstoppable.money/',
        availableOn: ['iOS', 'Android'],
    },
    {
        name: 'Stack Wallet',
        text: 'An open-source, non-custodial multichain wallet for eCash (XEC). Stack is a highly secure, privacy-first mobile wallet for XEC, available for Android and iOS smartphones.',
        image: '/images/stack-wallet.png',
        link: 'https://stackwallet.com/',
        availableOn: ['iOS', 'Android'],
    },
    {
        name: 'Satochip',
        text: 'Satochip is an open source and super-secure multi-crypto hardware wallet that natively supports storing eCash (XEC). Satochip cold wallet offers state-of-the-art security for storing & managing your XEC coins.',
        image: '/images/satochip.svg',
        link: 'https://satochip.io/',
        availableOn: ['Hardware Wallet'],
    },
    {
        name: "D'CENT",
        text: "D'CENT is another major hardware wallet that natively supports eCash (XEC). With the D’CENT biometric hardware wallet, you can securely send, receive, and manage your XEC coins.",
        image: '/images/dcent.svg',
        link: 'https://dcentwallet.com/',
        availableOn: ['Hardware Wallet'],
    },
    {
        name: 'Ballet',
        text: 'Ballet is a secure non-electronic physical wallet that offers native support for eCash (XEC). Safely store and easily manage your XEC coins with the Ballet cold wallet.',
        image: '/images/ballet.png',
        link: 'https://www.ballet.com/',
        availableOn: ['Hardware Wallet'],
    },
];
